@@ -14,7 +14,7 @@ use Module::Find;
 use Router::Simple;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '1.27';
+our $VERSION = '1.28';
 
 use constant {
 	BEFORE_DISPATCH    => 'before_dispatch',
@@ -132,7 +132,7 @@ sub body    { shift->res->body(@_) }
 
 sub method  {
 	my $self = shift;
-	return $self->param('_method') || $self->request->method(@_)
+	return uc($self->param('_method') || $self->request->method(@_))
 }
 
 sub conf {
